# -*- coding: utf-8 -*-
from setuphelpers import *

"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
processes_to_kill = "OneDrive.exe"


def install():
    # Disabling OneDrive in sys env
    killalltasks(processes_to_kill)

    registry_set(HKEY_LOCAL_MACHINE, r"SOFTWARE\Wow6432Node\Policies\Microsoft\Windows\OneDrive", "DisableFileSyncNGSC", 1, REG_DWORD)
    onedrive32 = makepath(system32, "OneDriveSetup.exe")
    onedrive64 = makepath(os.getenv("SystemRoot"), "SysWOW64", "OneDriveSetup.exe")
    if isfile(onedrive32):
        run_notfatal('"%s" /uninstall' % onedrive32)
    if isfile(onedrive64):
        run_notfatal('"%s" /uninstall' % onedrive64)


def uninstall():
    # Rolling back OneDrive disabling in sys env
    registry_delete(HKEY_LOCAL_MACHINE, r"SOFTWARE\Wow6432Node\Policies\Microsoft\Windows\OneDrive", "DisableFileSyncNGSC")


def session_setup():
    # Initializing variables
    user_app_dir = makepath(user_local_appdata, "Microsoft", "OneDrive")
    user_app_path = makepath(user_app_dir, "OneDrive.exe")

    # Killing app before actions
    killalltasks(processes_to_kill)

    # Uninstalling OneDrive in user env
    # "C:\Users\username\AppData\Local\Microsoft\OneDrive\20.143.0716.0003\OneDriveSetup.exe" /uninstall
    if isdir(user_app_dir):
        for setup_dir in glob.glob(makepath(user_app_dir, "**")):
            user_app_setup_path = makepath(setup_dir, "OneDriveSetup.exe")
            if isfile(user_app_setup_path):
                run_notfatal('"%s" /uninstall' % user_app_setup_path)

    # Disabling OneDrive regkey in user env
    registry_delete(HKEY_CURRENT_USER, r"Software\Microsoft\Windows\CurrentVersion\Run", "OneDriveSetup")
    registry_delete(HKEY_CURRENT_USER, r"Software\Microsoft\Windows\CurrentVersion\Run", "OneDrive")
    registry_delete(HKEY_CURRENT_USER, r"Microsoft\Windows\CurrentVersion\Explorer\StartupApproved\Run", "OneDriveSetup")
    registry_delete(HKEY_CURRENT_USER, r"Microsoft\Windows\CurrentVersion\Explorer\StartupApproved\Run", "OneDrive")

    # Removing OneDrive remaining files
    if isdir(user_app_path):
        remove_tree(user_app_path)
    remove_user_desktop_shortcut("OneDrive")
